#
# spec file for package snort (Version 1.8.1)
# 
# Copyright  (c)  2001  SuSE GmbH  Nuernberg, Germany.
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
# 
# please send bugfixes or comments to feedback@suse.de.
#

# neededforbuild  libnet libpcap
# usedforbuild    aaa_base aaa_dir autoconf automake base bash bindutil binutils bison bzip compress cpio cpp cracklib cyrus-sasl db devs diffutils e2fsprogs file fileutils findutils flex gawk gcc gdbm gdbm-devel gettext glibc glibc-devel gpm gppshare grep groff gzip kbd less libnet libpcap libtool libz m4 make man mktemp modutils ncurses ncurses-devel net-tools netcfg pam pam-devel patch perl ps rcs readline rpm sendmail sh-utils shadow strace syslogd sysvinit texinfo textutils timezone unzip util-linux vim

Name:         snort
Summary:      packet-sniffer/logger
Version:      1.8.1
Release:      32
%define 	SUBVERSION	RELEASE
Copyright:	GPL
Group:		Utilities/Security
Url:		http://snort.sourcefire.com/
Source0:	http://snort.sourcefire.com/releases/%{name}-%{version}-%{SUBVERSION}.tar.bz2
Source1:	snort-stat
Source2:	snortlog
Source3:	snort.init
Source4:	rc.config.snort
Source5:	5n0r7.c
Source6:	5n0r7.readme
BuildRoot:	/var/tmp/%{name}-root
Prefix:		/usr

%description
Snort is a libpcap-based packet sniffer and logger which
can be used as a lightweight network intrusion detection system.
It features rules based logging and can perform protocol analysis,
content searching and matching. It can be used to detect a variety of
attacks and probes, such as buffer overflows, stealth port scans,
CGI attacks, SMB probes, OS fingerprinting attempts, and much more.
Snort has a real-time alerting capabilty, with alerts being sent to syslog,
a separate "alert" file, or as a WinPopup message via Samba's smbclient.
Additionally, the snort-log-analyzer "5n0r7" is included.

Authors:
--------
    Marty Roesch <roesch@clark.net> (snort)
    Michel Kaempf <maxx@via.ecp.fr> (5n0r7)

SuSE series: sec

%prep
%setup -q -n %{name}-%{version}-%{SUBVERSION}
cp -a $RPM_SOURCE_DIR/5n0r7.{c,readme} .

%build
%{?suse_update_config:%{suse_update_config -f}}
CFLAGS="$RPM_OPT_FLAGS" 		\
./configure 	--prefix=/usr 		\
		--bindir=/usr/sbin 	\
		--sysconfdir=/etc/snort \
		--localstatedir=/var    \
		--mandir=%{_mandir}	\
		--enable-flexresp 	\
		--enable-smbalerts
make
gcc -O2 -o 5n0r7 5n0r7.c

%install
if [ "$RPM_BUILD_ROOT" = "/var/tmp/snort-root" ]; then
	rm -rf $RPM_BUILD_ROOT
	mkdir -p $RPM_BUILD_ROOT/usr/bin
	mkdir -p $RPM_BUILD_ROOT/usr/sbin
	mkdir -p $RPM_BUILD_ROOT/etc/snort
	mkdir -p $RPM_BUILD_ROOT/var/log/snort
	make DESTDIR=$RPM_BUILD_ROOT install
	install *.rules $RPM_BUILD_ROOT/etc/snort
	install snort.conf $RPM_BUILD_ROOT/etc/snort/snort.conf
	install classification.config $RPM_BUILD_ROOT/etc/snort/classification.config
	install -m 754 %{SOURCE1} %{SOURCE2} $RPM_BUILD_ROOT/usr/bin
	mkdir -p $RPM_BUILD_ROOT/usr/doc
	
else
	echo Invalid Build root
	exit 1
fi
install -d      ${RPM_BUILD_ROOT}/etc/init.d \
                ${RPM_BUILD_ROOT}%{prefix}/bin \
                ${RPM_BUILD_ROOT}%{prefix}/usr/sbin \
                ${RPM_BUILD_ROOT}/var/adm/fillup-templates
install -m 755 5n0r7 		${RPM_BUILD_ROOT}/usr/bin
install -m 755 %{SOURCE3}	${RPM_BUILD_ROOT}/etc/init.d/snort
install -m 755 ${RPM_SOURCE_DIR}/rc.config.snort	${RPM_BUILD_ROOT}/var/adm/fillup-templates/rc.config.snort
ln -sf          ../../etc/init.d/snort ${RPM_BUILD_ROOT}/usr/sbin/rcsnort
chmod 644 SnortUsersManual.pdf

%clean
if [ "$RPM_BUILD_ROOT" = "/var/tmp/snort-root" ]; then
	rm -rf $RPM_BUILD_ROOT
else
	echo Invalid Build root
	exit 1
fi
						

%post
LC_ALL=POSIX
sbin/insserv etc/init.d/snort
# Copy old configuration file to new name.
if [ $1 -gt 1 -a -f etc/snort/snort-lib ]; then
        echo "Moving snort configuration file snort-lib to new name snort.conf."
	test -f etc/snort/snort.conf && mv etc/snort/snort.conf etc/snort/snort.conf.rpmpost
	# Convert version 1.7 configuration file
	sed -e 's/^include \/etc\/snort\//include /g' \
		-e 's/-lib$/.rules/g' \
		etc/snort/snort-lib > etc/snort/snort.conf
	# Convert file reference in variable SNORT_OPTS
	umask 644
	sed -e 's/\/etc\/snort\/snort-lib/\/etc\/snort\/snort.conf/g' \
		etc/rc.config > etc/rc.config.new-snort
	# Check size of new file; must be 1 byte bigger
	echo "Convert file reference from snort-lib to snort.conf in etc/rc.config"
	if [ $(($( find etc/rc.config -printf "%s")+1)) -eq \
	  	$( find etc/rc.config.new-snort -printf "%s") ]; then
		mv etc/rc.config.new-snort etc/rc.config
	else
		echo "ERROR: new etc/rc.config doesn't match the expacted file size."
		echo "Please check the content of SNORT_OPTS and set it to the one from"
		echo "var/adm/fillup-templates/rc.config.snort"
	fi
fi
echo "Updating etc/rc.config..."
if [ -x bin/fillup ] ; then
  bin/fillup -q -d = etc/rc.config var/adm/fillup-templates/rc.config.snort
else
  echo "ERROR: fillup not found. This should not happen. Please compare"
  echo "etc/rc.config and var/adm/fillup-templates/rc.config.snort and"
  echo "update by hand."
fi
cat << EOF > var/adm/notify/messages/snort-notify
Hallo,  (english text below)
 
die Hauptkonfigurationsdatei /etc/snort/snort-lib wurde von den
Entwicklern des Paketes mit der Version 1.8 nach /etc/snort/snort.conf
umbenannt. Zudem wurde teilweise das Format der Konfigurationsdatei
geaendert. Im Rahmen eines Updates wird die Konvertierung Ihrer
vorhandenen Konfiguration versucht. In diesem Fall finden Sie die der
aktuellen Version beiliegende Beispielkonfiguration mit der
zusaetzlichen Endung .rpmpost.
 
Bitte ueberpruefen Sie trotzdem den Inhalt der Variable SNORT_OPTS in
/etc/rc.config und aendern Sie gegebenenfalls dort per Hand den Verweis
von /etc/snort/snort-lib auf /etc/snort/snort.conf.
 
 
Hello,
 
the main configuration file /etc/snort/snort-lib was renamed by the
authors of the package from version 1.8 on to /etc/snort/snort.conf.
Additionally the format of the file was changed. Due to this while an
update the conversion will be attempted. In this case you find the
example configuration file with an ending .rpmpost.
 
Even so please check the content of the SNORT_OPTS variable in
/etc/rc.config and if necessary change the value from
/etc/snort/snort-lib to /etc/snort/snort.conf.
 
Have a lot of fun...
			Your SuSE Team
EOF

%postun
sbin/insserv etc/init.d/

%files
%defattr(-,root,root)
%attr(644,root,root) %config	/etc/snort/*.config
%attr(644,root,root) %config	/etc/snort/*.rules
%attr(644,root,root) %config(noreplace)	/etc/snort/*.conf
%attr(755,root,root)	/usr/sbin/*
%attr(755,root,root)	/usr/bin/*
%dir	/etc/snort
%attr(755,root,root) %dir	/var/log/snort
%doc %{_mandir}/man8/snort.8.gz
%doc AUTHORS BUGS COPYING CREDITS ChangeLog INSTALL NEWS README* USAGE 5n0r7.readme LICENSE RULES* SnortUsersManual.pdf
/etc/init.d/snort
/var/adm/fillup-templates/rc.config.snort

%changelog -n snort
* Thu Sep 06 2001 - schwab@suse.de
- Remove extra text from rc.config.snort.
* Sun Aug 26 2001 - mge@suse.de
- updated 5n0r7.c to new log-file-format.
  Thanks to Michel "MaXX" Kaempf <maxx@via.ecp.fr>
-  fixed /etc/init.d/snort status-handling (bug #9095)
* Fri Aug 24 2001 - lmuelle@suse.de
- Remove Requires: libpcapn libnet
- Split 5n0r7.c.diff in 5n0r7.c and 5n0r7.readme and put rc.config parts
  in source files
* Fri Aug 24 2001 - lmuelle@suse.de
- Update to 1.8.1; fixes outstanding bugs; more stable than 1.8
  New features: SNMP alerts, IDMEF XML output, limited wildcard regex
  support, new normilization mode for http_decode
- Main configuration file moved in upstream from /etc/snort/snort-lib
  to /etc/snort/snort.conf
- Convert old configuration file, if necessary, while update
- Convert SNORT_OPTS config file oriented part while update in rc.config
- Include SnortUsersManual.pdf and snort man page
* Thu Aug 09 2001 - ro@suse.de
- use libpcap instead of (dropped) libpcapn
* Thu May 10 2001 - mfabian@suse.de
- bzip2 sources
* Thu Jan 25 2001 - mge@suse.de
- update to snort-1.7
- fixed bugzilla bugs: #5187, #5366
- "notify" for yast, to configure "/etc/snort/snort-lib"
* Mon Dec 04 2000 - mge@suse.de
- update to snort-1.6.3-patch2, new /etc/init.d handling
* Mon Jul 24 2000 - mge@suse.de
- update to 1.6.3
* Thu Jul 13 2000 - mge@suse.de
- added symlinks to /etc/rc.d/rc2.d /etc/rc.d/rc3.d
* Fri Jul 07 2000 - mge@suse.de
- initial SuSE RPM
- added 5n0r7 by Michel Kaempf <maxx@via.ecp.fr>
  ftp://snort.via.ecp.fr/5n0r7/5n0r7.c
* Tue Mar 28 2000 - William Stearns <wstearns@pobox.com>
- Quick update to 1.6.
- Sanity checks before doing rm-rf in install and clean
* Fri Dec 10 1999 - Henri Gomez <gomez@slib.fr>
- 1.5-0 Initial RPM release
